@@ -19,7 +19,6 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s،%2$sو%3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s،%2$s،%3$sو%4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s،%2$s،%3$s،%4$sو%5$s",
-    "Education Edition" : "نگارش آموزشی",
     "Enterprise bundle" : "بستهٔ سازمانی",
     "Groupware bundle" : "بستهٔ کار گروهی",
     "Hub bundle" : "بستهٔ هسته‌ای",
@@ -76,26 +75,25 @@ OC.L10N.register(
     "seconds ago" : "ثانیه‌ها پیش",
     "Empty file" : "پروندهٔ خالی",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "ماژول با شناسه:%s وجود ندارد. لطفاً آن را در تنظیمات برنامه خود فعال کنید یا با سرپرست خود تماس بگیرید",
+    "Dot files are not allowed" : "پرونده‌های نقطه‌دار مجاز نیستند",
     "File already exists" : "پرونده از پیش موجود است",
     "Invalid path" : "مسیر نامعتبر",
     "Failed to create file from template" : "شکست در ایجاد پرونده از قالب",
     "Templates" : "قالب‌ها",
-    "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
-    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
-    "File name is too long" : "نام فایل خیلی بزرگ است",
-    "Dot files are not allowed" : "پرونده‌های نقطه‌دار مجاز نیستند",
+    "Filename contains at least one invalid character" : "نام فایل حداقل دارای یک کاراکتر نامعتبر است",
     "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "کارهٔ «%s» به دلیل ناتوانی در خواندن پروندهٔ appinfo نمی‌تواند نصب شود.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "کارهٔ «%s» به دلیل سازگار نبودن با این نگارش از کارساز نمی‌تواند نصب شود.",
     "__language_name__" : "فارسى",
     "This is an automatically sent email, please do not reply." : "این یک رایانامهٔ خودکار است. لطفاً پاسخ ندهید.",
+    "Help & privacy" : "راهنما و حریم شخصی",
     "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
     "Apps" : "  برنامه ها",
     "Personal settings" : "تنظیمات شخصی",
     "Administration settings" : "تنظمیات مدیریتی",
     "Settings" : "تنظیمات",
     "Log out" : "خروج",
-    "Users" : "کاربران",
+    "Accounts" : "حساب‌ها",
     "Email" : "رایانامه",
     "Mail %s" : "نامه به %s",
     "Fediverse" : "Fediverse",
@@ -127,11 +125,8 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "به اشتراک گذاشتن باطن باید رابط OCP \\ Share_Backend %sرا پیاده سازی کند",
     "Sharing backend %s not found" : "به اشتراک گذاشتن باطن%s یافت نشد",
     "Sharing backend for %s not found" : "به اشتراک گذاشتن باطن برای%s یافت نشد",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
-    "»%s« added a note to a file shared with you" : "»%s« یادداشتی را به پرونده ای که با شما به اشتراک گذاشته شده است اضافه کرد",
-    "Open »%s«" : "باز کن »%s«",
     "%1$s via %2$s" : "%1$s از طریق %2$s",
+    "Unknown share type" : "نوع اشتراک ناشناخته",
     "You are not allowed to share %s" : "شما مجاز به اشتراک گذاری نیستید%s",
     "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
     "Files cannot be shared with delete permissions" : "Files cannot be shared with delete permissions",
@@ -139,9 +134,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "تاریخ انقضا در گذشته است",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Cannot set expiration date more than %n day in the future","Cannot set expiration date more than %n days in the future"],
     "Sharing is only allowed with group members" : "Sharing is only allowed with group members",
-    "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
-    "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
-    "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
     "The requested share does not exist anymore" : "سهم درخواست شده دیگر وجود ندارد",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "The user was not created because the user limit has been reached. Check your notifications to learn more.",
     "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
@@ -194,8 +186,6 @@ OC.L10N.register(
     "Login canceled by app" : "ورود به دست کاره لغو شد",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "کارهٔ «%1$s» نمی‌تواند نصب شود؛ چرا که وابستگی زیر تأمین نشده: %2$s",
     "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
-    "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
-    "Cannot download file" : "نمی‌توان پرونده را بارگرفت",
     "Application is not enabled" : "برنامه فعال نشده است",
     "Authentication error" : "خطا در اعتبار سنجی",
     "Token expired. Please reload page." : "Token منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
@@ -226,7 +216,6 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Your data directory must be an absolute path.",
     "Check the value of \"datadirectory\" in your configuration." : "Check the value of \"datadirectory\" in your configuration.",
     "Your data directory is invalid." : "Your data directory is invalid.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "اطمینان حاصل کنید که فایلی به نام \".ocdata\" در ریشه دایرکتوری داده وجود دارد.",
     "Action \"%s\" not supported or implemented." : "عملی%s پشتیبانی یا اجرا نشده است.",
     "Authentication failed, wrong token or provider ID given" : "تأیید اعتبار انجام نشد ، نشانه اشتباه یا شناسه ارائه دهنده داده شد",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "پارامترهای موجود برای تکمیل درخواست. پارامترهای موجود نیست%s",
@@ -238,19 +227,31 @@ OC.L10N.register(
     "Storage connection error. %s" : "خطای اتصال ذخیره سازی%s",
     "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
     "Storage connection timeout. %s" : "مدت زمان اتصال ذخیره سازی%s",
+    "Confirmation" : "Confirmation",
+    "Prompt" : "Prompt",
+    "Chat" : "Chat",
+    "Generates a possible headline for a text." : "Generates a possible headline for a text.",
+    "Text" : "متن",
+    "Summarize" : "Summarize",
+    "Summary" : "چکیده",
+    "Extract topics" : "Extract topics",
+    "Translate" : "ترجمه",
+    "Target language" : "Target language",
+    "Result" : "شروع به اسکنیک",
     "Free prompt" : "Free prompt",
     "Runs an arbitrary prompt through the language model." : "Runs an arbitrary prompt through the language model.",
     "Generate headline" : "Generate headline",
-    "Generates a possible headline for a text." : "Generates a possible headline for a text.",
-    "Summarize" : "Summarize",
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
-    "Extract topics" : "Extract topics",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
-    "404" : "۴۰۴",
+    "Education Edition" : "نگارش آموزشی",
     "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub admin or gotten special right to access this setting",
     "Logged in user must be an admin or sub admin" : "ورود به سیستم کاربر باید یک مدیر یا مدیر فرعی باشد",
     "Logged in user must be an admin" : "ورود به سیستم کاربر باید مدیر سایت باشد",
-    "Help" : "راه‌نما",
+    "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
+    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
+    "File name is too long" : "نام فایل خیلی بزرگ است",
+    "Help" : "راهنما",
+    "Users" : "کاربران",
     "Unknown user" : "کاربر نامعلوم",
     "Enter the database username and name for %s" : "ورود نام و نام کاربری پایگاه داده برای %s",
     "Enter the database username for %s" : "ورود نام کاربری پایگاه داده برای %s",
@@ -258,7 +259,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
     "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
     "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s به اشتراک گذاشته شده »%2$s« با شماست و می خواهد اضافه کند:",
+    "»%s« added a note to a file shared with you" : "»%s« یادداشتی را به پرونده ای که با شما به اشتراک گذاشته شده است اضافه کرد",
+    "Open »%s«" : "باز کن »%s«",
     "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
+    "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
+    "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
+    "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
     "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
     "Could not create user" : "نتواسنت کاربر را ایجاد کند",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
@@ -267,9 +275,10 @@ OC.L10N.register(
     "Username must not consist of dots only" : "نام کاربری نباید فقط از نقاط تشکیل شده باشد",
     "Username is invalid because files already exist for this user" : "Username is invalid because files already exist for this user",
     "User disabled" : "کاربر از کار افتاده",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 required.",
-    "Please upgrade your database version." : "Please upgrade your database version.",
+    "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
+    "Cannot download file" : "نمی‌توان پرونده را بارگرفت",
     "Your data directory is readable by other users." : "Your data directory is readable by other users.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود."
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود.",
+    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "اطمینان حاصل کنید که فایلی به نام \".ocdata\" در ریشه دایرکتوری داده وجود دارد."
 },
 "nplurals=2; plural=(n > 1);");
