@@ -122,14 +122,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
     "Sharing backend %s not found" : "Ozadnjega programa %s za souporabo ni mogoče najti",
     "Sharing backend for %s not found" : "Ozadnjega programa za souporabo za %s ni mogoče najti",
-    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
-    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
-    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
-    "Open »%s«" : "Odpri »%s«",
     "%1$s via %2$s" : "%1$s prek %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vam omogoča souporabo »%2$s« in želi dodati:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s vam omogoča souporabo »%2$s« in želi dodati",
-    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
     "Unknown share type" : "Neznana vrsta mesta souporabe",
     "You are not allowed to share %s" : "Omogočanje souporabe %s brez ustreznih dovoljenj ni mogoče.",
     "Cannot increase permissions of %s" : "Ni mogoče povečati dovoljen %s",
@@ -228,8 +221,10 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
     "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "Če želite omogočiti izvajanje tega preverjanja, je treba zagotoviti, da se spletni strežnik lahko poveže sam s seboj. Zato mora biti nastavljen za povezovanje z vsaj eno od določenih »varnih domen« (trusted_domains) ali naslovov za prepis »vmesnika ukazne vrstice« (overwrite.cli.url). Spodletelo preverjanje je lahko posledica neujemanja imen DNS na strani strežnika oziroma pravila požarnega zidu.",
+    "Confirmation" : "Potrjevanje",
     "Writing style" : "Slog pisanja",
     "Generate image" : "Ustvari sliko",
+    "Text" : "Besedilo",
     "Summary" : "Povzetek",
     "Translate" : "Prevedi",
     "Target language" : "Ciljni jezik",
@@ -250,7 +245,14 @@ OC.L10N.register(
     "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
     "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
     "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
+    "%1$s shared »%2$s« with you and wants to add:" : "%1$s vam omogoča souporabo »%2$s« in želi dodati:",
+    "%1$s shared »%2$s« with you and wants to add" : "%1$s vam omogoča souporabo »%2$s« in želi dodati",
+    "»%s« added a note to a file shared with you" : "»%s« doda opombo k datoteki v souporabi",
+    "Open »%s«" : "Odpri »%s«",
     "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet že v souporabi z uporabnikom %s.",
+    "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
+    "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
+    "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
     "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
     "Could not create user" : "Uporabnika ni mogoče ustvariti",
     "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: »a–z«, »A–Z«, »0–9«, presledki in »_.@-«\".",
